@@ -17,8 +17,10 @@ from bigdata_client.api.chat import (
     ChatAskRequest,
     ChatResponse,
     ChatWSAuditTraceResponse,
+    ChatWSCompleteEnrichedResponse,
     ChatWSCompleteResponse,
     ChatWSNextResponse,
+    ChatWSSourcesResponse,
     CreateNewChat,
     GetChatListResponse,
 )
@@ -53,6 +55,7 @@ from bigdata_client.api.uploads import (
     FileResponse,
     FileStatus,
     GetDownloadPresignedUrlResponse,
+    GetFileIndexStatusResponse,
     GetFileStatusResponse,
     ListFilesResponse,
     PostFileRequest,
@@ -68,7 +71,13 @@ from bigdata_client.api.watchlist import (
     UpdateSingleWatchlistResponse,
     UpdateWatchlistRequest,
 )
-from bigdata_client.auth import AsyncRequestContext, AsyncResponseContext, Auth, WSAuth
+from bigdata_client.auth import (
+    AsyncRequestContext,
+    AsyncResponseContext,
+    BaseAuth,
+    Proxy,
+    WSAuth,
+)
 from bigdata_client.connection_management import RequestsPerMinuteController
 from bigdata_client.constants import (
     MAX_REQUESTS_PER_MINUTE,
@@ -143,19 +152,40 @@ class BigdataConnection:
     For internal use only.
     """
 
-    def __init__(self, auth: Auth, backend_url: str, websocket_url: str):
+    def __init__(self, auth: BaseAuth, backend_url: str, websocket_url: str):
         self.http = RateLimitedHTTPWrapper(auth, backend_url)
-        self.ws = WSWrapper(auth, websocket_url)
+        self.ws = WSWrapper(
+            auth, websocket_url, proxies=auth.proxies, verify=auth.verify
+        )
 
     # Autosuggest
 
     def autosuggest(
-        self, item: str, limit: int, categories: Optional[list[FilterAnalyticCategory]]
+        self,
+        item: Optional[str],
+        limit: int,
+        categories: Optional[list[FilterAnalyticCategory]],
+        group1: Optional[list[str]],
+        group2: Optional[list[str]],
+        group3: Optional[list[str]],
+        group4: Optional[list[str]],
+        group5: Optional[list[str]],
     ) -> list[KnowledgeGraphTypes]:
         """Calls POST /autosuggest/search"""
+        if item is None:
+            item = ""
         json_response = self.http.post(
             "autosuggest/search",
-            json={"query": item, "perPage": limit, "category": categories},
+            json={
+                "query": item,
+                "perPage": limit,
+                "category": categories,
+                "group1": group1,
+                "group2": group2,
+                "group3": group3,
+                "group4": group4,
+                "group5": group5,
+            },
         )
         return [parse_autosuggest_response(item) for item in json_response["results"]]
 
@@ -293,7 +323,7 @@ class BigdataConnection:
         """Calls POST /user-data/watchlists"""
         json_request = request.model_dump(exclude_none=True, by_alias=True)
 
-        json_response = self.http.post(f"user-data/watchlists", json=json_request)
+        json_response = self.http.post("user-data/watchlists", json=json_request)
 
         return CreateWatchlistResponse.model_validate(json_response)
 
@@ -349,7 +379,7 @@ class BigdataConnection:
 
     def get_my_quota(self) -> MyBigdataQuotaResponse:
         """Calls GET /user-data/quota"""
-        json_response = self.http.get(f"user-data/quota")
+        json_response = self.http.get("user-data/quota")
         return MyBigdataQuotaResponse(**json_response)
 
     def get_companies_by_isin(self, isins: list[str]) -> list[Optional[Company]]:
@@ -368,6 +398,11 @@ class BigdataConnection:
         json_response = self.http.post("/cqs/companies/listing", json=listings)
         return self._format_company_from_cqs_response(listings, json_response)
 
+    def send_tracking_event(self, trace_event: "TraceEvent"):  # noqa: F821
+        return self.http.post(
+            "/track-events", json=trace_event.model_dump(exclude_none=True)
+        )
+
     def get_chat(self, id_: str) -> ChatResponse:
         json_response = self.http.get(f"/user-data/chats/{id_}")
         return ChatResponse(**json_response)
@@ -384,17 +419,34 @@ class BigdataConnection:
         return ChatResponse(**json_response)
 
     def ask_chat(
-        self, id_: str, question: str, *, scope: Optional[str] = None
+        self,
+        id_: str,
+        question: str,
+        *,
+        scope: Optional[str] = None,
+        source_filter: Optional[list[str]] = None,
     ) -> Generator[
-        Union[str, ChatWSCompleteResponse, ChatWSAuditTraceResponse], None, None
+        Union[
+            str,
+            ChatWSCompleteEnrichedResponse,
+            ChatWSAuditTraceResponse,
+            ChatWSSourcesResponse,
+        ],
+        None,
+        None,
     ]:
         request_id = str(uuid.uuid4())
         msg = ChatAskRequest(
-            chat_id=id_, input_message=question, request_id=request_id, scope=scope
+            chat_id=id_,
+            input_message=question,
+            request_id=request_id,
+            scope=scope,
+            sources=source_filter,
         )
         with self.ws.get_ws_auth() as ws:
             ws.send(msg.model_dump(by_alias=True))
             wait_timeout = WaitTimeout(SECONDS_WAITING_CHAT_RESPONSE)
+            next_contents = []
             for _ in wait_timeout:
                 try:
                     response = ws.recv()
@@ -412,11 +464,20 @@ class BigdataConnection:
 
                 if response_type == "NEXT":
                     next_data = ChatWSNextResponse.model_validate(response)
+                    next_contents.append(next_data.content)
                     yield next_data.content
 
+                if response_type == "SOURCES":
+                    sources_data = ChatWSSourcesResponse.model_validate(response)
+                    yield sources_data
+
                 if response_type == "COMPLETE":
                     complete_message = ChatWSCompleteResponse.model_validate(response)
-                    yield complete_message
+                    complete_enriched_message = ChatWSCompleteEnrichedResponse(
+                        **complete_message.model_dump(),
+                        aggregated_next_content="".join(next_contents),
+                    )
+                    yield complete_enriched_message
                     break
             if wait_timeout.timeout_reached:
                 raise TimeoutError("Timeout waiting for chat response")
@@ -450,7 +511,7 @@ class UploadsConnection:
     For internal use only.
     """
 
-    def __init__(self, auth: Auth, api_url: str, organization_id: str):
+    def __init__(self, auth: BaseAuth, api_url: str, organization_id: Optional[str]):
         self.http = HTTPWrapper(auth, api_url)
         # organization_id is set at this level so when an object performs an action that requires it (e.g: sharing)
         # it won't need to get & store its value, instead the sharing method already has it.
@@ -499,6 +560,10 @@ class UploadsConnection:
         json_response = self.http.get(f"files/{file_id}/status")
         return GetFileStatusResponse(**json_response)
 
+    def get_file_index_status(self, file_id: str) -> GetFileIndexStatusResponse:
+        json_response = self.http.get(f"files/{file_id}/index-status")
+        return GetFileIndexStatusResponse(**json_response)
+
     def delete_file(self, file_id: str) -> DeleteFileResponse:
         response = self.http.delete(f"files/{file_id}")
         return DeleteFileResponse(**response)
@@ -521,6 +586,11 @@ class UploadsConnection:
         )
 
     def share_file_with_company(self, file_id: str) -> FileResponse:
+        if not self._organization_id:
+            raise NotImplementedError(
+                "Sharing an item with the organization is not possible with the used auth method."
+            )
+
         share_model = {"shared_with": [self._organization_id]}
         json_response = self.http.patch(f"files/{file_id}/metadata", json=share_model)
         return FileResponse(**json_response)
@@ -532,7 +602,7 @@ class UploadsConnection:
 
     def get_my_quota(self) -> MyUploadQuotaResponse:
         """Calls GET /1.0/quota"""
-        json_response = self.http.get(f"quota")
+        json_response = self.http.get("quota")
         return MyUploadQuotaResponse(**json_response)
 
     def update_file_tags(self, file_id: str, tags: list[str]) -> FileResponse:
@@ -611,7 +681,7 @@ class HTTPWrapper:
     A basic connection to perform authenticated HTTP GET, POST, PATCH, DELETE requests.
     """
 
-    def __init__(self, auth: Auth, api_url: str):
+    def __init__(self, auth: BaseAuth, api_url: str):
         self.auth = auth
         self.api_url = api_url
 
@@ -733,7 +803,7 @@ class HTTPWrapper:
 class RateLimitedHTTPWrapper(HTTPWrapper):
     """Extension on HTTPWrapper that applies rate limiting to synchronous requests"""
 
-    def __init__(self, auth: Auth, api_url: str):
+    def __init__(self, auth: BaseAuth, api_url: str):
         super().__init__(auth, api_url)
         self.request_controller = RequestsPerMinuteController(
             max_requests_per_min=MAX_REQUESTS_PER_MINUTE,
@@ -747,9 +817,22 @@ class RateLimitedHTTPWrapper(HTTPWrapper):
 
 
 class WSWrapper:
-    def __init__(self, auth: Auth, api_url: str):
+    def __init__(
+        self,
+        auth: BaseAuth,
+        api_url: str,
+        proxies: Optional[dict],
+        verify: Union[bool, str],
+    ):
         self.auth = auth
         self.api_url = api_url
+        self.proxies = proxies
+        self.verify = verify
 
     def get_ws_auth(self) -> WSAuth:
-        return self.auth.get_ws_auth(self.api_url)
+        proxy = (
+            Proxy(url=self.proxies["wss"], protocol="wss")
+            if (self.proxies and self.proxies.get("wss"))
+            else None
+        )
+        return self.auth.get_ws_auth(self.api_url, proxy=proxy, verify=self.verify)
