@@ -16,11 +16,14 @@ class BigdataConnectionProtocol(Protocol):
 
     def share_unshare_watchlist(self, id_, request): ...
 
-    def autosuggest(self, items, limit, categories): ...
+    def autosuggest(
+        self, items, limit, categories, group1, group2, group3, group4, group5
+    ): ...
 
     def autosuggest_async(self, items, limit): ...
 
-    def by_ids(self, request): ...
+    def by_ids(self, request) -> "ByIdsResponse":  # noqa
+        ...
 
     def share_file_with_company(self, file_id): ...
 
@@ -44,4 +47,11 @@ class BigdataConnectionProtocol(Protocol):
 
     def delete_chat(self, id_): ...
 
-    def ask_chat(self, id_, question, *, scope: Optional[str] = None): ...
+    def ask_chat(
+        self,
+        id_,
+        question,
+        *,
+        scope: Optional[str] = None,
+        source_filter: Optional[list[str]] = None,
+    ): ...
