@@ -938,28 +938,6 @@ class ReportingPeriodWrapper(ListQueryComponent):
         return cls(*self.items, *other.items, operation=operation)
 
 
-# Watchlist is a special case, as it's not a list of items
-
-
-class Watchlist(BaseQueryComponent):
-    def __init__(self, watchlist_id: str):
-        self.watchlist_id = watchlist_id
-
-    def to_expression(self) -> Expression:
-        return Expression(
-            type=ExpressionTypes.WATCHLIST,
-            operation=ExpressionOperation.IN,
-            value=self.watchlist_id,
-        )
-
-    def __repr__(self):
-        return f"Watchlist({repr(self.watchlist_id)})"
-
-    def make_copy(self) -> QueryComponent:
-        """Make a deep copy of the query component"""
-        return Watchlist(watchlist_id=self.watchlist_id)
-
-
 class AbsoluteDateRangeQuery(BaseQueryComponent):
     def __init__(self, start: str, end: str):
         self.start = start
@@ -1118,8 +1096,6 @@ def _expression_to_query_component(expression: Expression) -> QueryComponent:
         return Language(*expression.value, operation=expression.operation)
     if expression.type == ExpressionTypes.SOURCE:
         return Source(*expression.value, operation=expression.operation)
-    if expression.type == ExpressionTypes.WATCHLIST:
-        return Watchlist(expression.value)
     if expression.type == ExpressionTypes.DATE:
         if isinstance(expression.value, list):
             return AbsoluteDateRangeQuery(*expression.value)
