@@ -12,8 +12,8 @@ class QuotaConsumption(BaseModel):
 
 class OrganizationQuota(BaseModel):
     query_unit: QuotaConsumption
-    file_upload_pages: QuotaConsumption
-    pdf_upload_pages: QuotaConsumption
+    file_upload_pages: Optional[QuotaConsumption] = None
+    pdf_upload_pages: Optional[QuotaConsumption] = None
 
 
 class SubscriptionDetails(BaseModel):
