@@ -16,6 +16,7 @@ from bigdata_client.constants import DEPRECATED_WARNING_AUTOSUGGEST
 from bigdata_client.enum_utils import StrEnum
 from bigdata_client.models.entities import (
     Company,
+    CompanyType,
     Concept,
     Etf,
     MacroEntity,
@@ -25,7 +26,12 @@ from bigdata_client.models.entities import (
     Product,
 )
 from bigdata_client.models.languages import Language
-from bigdata_client.models.sources import Source
+from bigdata_client.models.sources import (
+    Source,
+    SourceCountry,
+    SourceRank,
+    SourceRetentionPeriod,
+)
 from bigdata_client.models.topics import Topic
 from bigdata_client.query_type import QueryType
 
@@ -67,11 +73,25 @@ class KnowledgeGraph:
 
     def _autosuggest(
         self,
-        value: str,
+        value: Optional[str],
         limit: int,
         categories: Optional[list[FilterAnalyticCategory]] = None,
+        group1: Optional[list[str]] = None,
+        group2: Optional[list[str]] = None,
+        group3: Optional[list[str]] = None,
+        group4: Optional[list[str]] = None,
+        group5: Optional[list[str]] = None,
     ) -> list[KnowledgeGraphTypes]:
-        return self._api.autosuggest(value, limit=limit, categories=categories)
+        return self._api.autosuggest(
+            value,
+            limit=limit,
+            categories=categories,
+            group1=group1,
+            group2=group2,
+            group3=group3,
+            group4=group4,
+            group5=group5,
+        )
 
     def _autosuggest_async(
         self,
@@ -252,14 +272,26 @@ class KnowledgeGraph:
     @overload
     @deprecated(DEPRECATED_WARNING_AUTOSUGGEST)
     def find_companies(
-        self, values: list[str], /, limit=20
+        self, values: list[str], /, limit: int = 20
     ) -> dict[str, list[Company]]: ...
 
     @overload
-    def find_companies(self, values: str, /, limit=20) -> list[Company]: ...
+    def find_companies(
+        self,
+        values: Optional[str] = None,
+        /,
+        type: Optional[Union[CompanyType, list[CompanyType]]] = None,
+        country: Optional[Union[str, list[str]]] = None,
+        limit: int = 20,
+    ) -> list[Company]: ...
 
     def find_companies(
-        self, values: Union[list[str], str], /, limit=20
+        self,
+        values: Optional[Union[list[str], str]] = None,
+        /,
+        type: Optional[Union[CompanyType, list[CompanyType]]] = None,
+        country: Optional[Union[str, list[str]]] = None,
+        limit: int = 20,
     ) -> Union[dict[str, list[Company]], list[Company]]:
         """
         Searches for values in the Knowledge Graph and filters out anything that is not a company.
@@ -271,7 +303,8 @@ class KnowledgeGraph:
 
             Args:
                 values: Searched item (str)
-
+                type: Company type (Public, Private)
+                country: Country (US, ES, ...)
                 limit: Upper limit for each result before applying the filter
 
             Returns:
@@ -287,11 +320,37 @@ class KnowledgeGraph:
             Returns:
                 Dict with the searched terms as keys each with a list of results.
         """
-        return self._autosuggest_and_filter(
+        if values is None and type is None and country is None:
+            raise ValueError(
+                "At least one of the parameters 'values', 'type' or 'country' must be provided."
+            )
+        types = [type] if isinstance(type, CompanyType) else type
+        countries = [country] if isinstance(country, str) else country
+
+        try:
+            if countries:
+                countries = [
+                    SourceCountry[country.upper()].value for country in countries
+                ]
+        except KeyError:
+            raise ValueError(
+                f"Invalid or not supported Country value: '{countries}'. Please use an ISO-3166-1 alpha-2 code."
+            )
+
+        response = self._autosuggest_and_filter(
             allowed_category=FilterAnalyticCategory.COMPANIES,
             values=values,
             limit=limit,
+            group1=types,
+            group2=countries,
         )
+        # Reverse mapping country names only if new response format is used
+        if isinstance(response, list):
+            for company in response:
+                company.country = SourceCountry.get_reverse_mapping().get(
+                    company.country
+                )
+        return response
 
     @overload
     @deprecated(DEPRECATED_WARNING_AUTOSUGGEST)
@@ -466,10 +525,28 @@ class KnowledgeGraph:
     ) -> dict[str, list[Source]]: ...
 
     @overload
-    def find_sources(self, values: str, /, limit=20) -> list[Source]: ...
+    def find_sources(
+        self,
+        values: Optional[str] = None,
+        /,
+        limit=20,
+        country: Optional[Union[list[str], str]] = None,
+        rank: Optional[Union[list[SourceRank], SourceRank]] = None,
+        retention: Optional[
+            Union[list[SourceRetentionPeriod], SourceRetentionPeriod]
+        ] = None,
+    ) -> list[Source]: ...
 
     def find_sources(
-        self, values: Union[list[str], str], /, limit=20
+        self,
+        values: Optional[Union[list[str], str]] = None,
+        /,
+        limit=20,
+        country: Optional[Union[list[str], str]] = None,
+        rank: Optional[Union[list[SourceRank], SourceRank]] = None,
+        retention: Optional[
+            Union[list[SourceRetentionPeriod], SourceRetentionPeriod]
+        ] = None,
     ) -> Union[dict[str, list[Source]], list[Source]]:
         """
         Searches for values in the Knowledge Graph and filters out anything that is not a source.
@@ -480,10 +557,15 @@ class KnowledgeGraph:
         * Implementation 1
 
             Args:
-                values: Searched item (str)
+                values: Searched item (str), leave as None to only apply the rest of the filters
 
                 limit: Upper limit for each result before applying the filter
 
+                country: Optional country ISO-3166-1 alpha-2 to filter sources by
+
+                rank: Optional rank to filter sources by
+
+                retention: Optional retention period to filter sources by
             Returns:
                 List of results.
 
@@ -497,10 +579,40 @@ class KnowledgeGraph:
             Returns:
                 Dict with the searched terms as keys each with a list of results.
         """
-        return self._autosuggest_and_filter(
-            allowed_category=FilterAnalyticCategory.SOURCES, values=values, limit=limit
+        if values is None:
+            values = ""
+        countries = [country] if isinstance(country, str) else country
+        ranks = [rank] if isinstance(rank, SourceRank) else rank
+        retentions = (
+            [retention] if isinstance(retention, SourceRetentionPeriod) else retention
         )
 
+        if countries:
+            try:
+                countries = [SourceCountry[country.upper()] for country in countries]
+            except KeyError:
+                raise ValueError(
+                    f"Invalid or not supported Country value: '{country}'. Please use an ISO-3166-1 alpha-2 code."
+                )
+
+        results = self._autosuggest_and_filter(
+            allowed_category=FilterAnalyticCategory.SOURCES,
+            values=values,
+            limit=limit,
+            group3=countries,
+            group4=ranks,
+            group5=retentions,
+        )
+
+        if isinstance(results, dict):
+            # Deprecated implementation
+            return results
+        elif isinstance(results, list):
+            # Reverse mapping country names to ISO-3166-1 alpha-2
+            for source in results:
+                source.replace_country_by_iso3166()
+            return results
+
     @overload
     @deprecated(DEPRECATED_WARNING_AUTOSUGGEST)
     def find_topics(self, values: list[str], /, limit=20) -> dict[str, list[Topic]]: ...
@@ -545,8 +657,13 @@ class KnowledgeGraph:
     def _autosuggest_and_filter(
         self,
         allowed_category: FilterAnalyticCategory,
-        values: Union[list[str], str],
+        values: Optional[Union[list[str], str]],
         limit: int,
+        group1: Optional[list[str]] = None,
+        group2: Optional[list[str]] = None,
+        group3: Optional[str] = None,
+        group4: Optional[str] = None,
+        group5: Optional[str] = None,
     ) -> Union[dict, list]:
         if isinstance(values, list):
             # Decorator not displaying the msg
@@ -562,9 +679,16 @@ class KnowledgeGraph:
 
             return dict(results.root.items())
 
-        if isinstance(values, str):
+        if isinstance(values, str) or values is None:
             return self._autosuggest(
-                value=values, limit=limit, categories=[allowed_category]
+                value=values,
+                limit=limit,
+                categories=[allowed_category],
+                group1=group1,
+                group2=group2,
+                group3=group3,
+                group4=group4,
+                group5=group5,
             )
 
         raise TypeError(f"Expected list or str for @values, found {type(values)}")
